@@ -3,17 +3,7 @@
 #                  Spawning Stock Biomass Per Recruit Analysis                #
 #					                                                #          
 ###############################################################################
-#age<-c(2,3,4,5,6,7)               #ages
-#ssbwgt<-c(0.091,0.196,0.303,0.585,0.846,0.846)             #average catch weight at age
-#prec<-c(0.17,0.60,1,1,1,1)   
-#pmat<-c(0.1,0.75,1,1,1,1)                                   #partial recruitment vector
-#M<-0.4                                             #natural mortality
-#maxF<-2							    #maximum F for analysis
-#pF<-0.5                                             #prop. F before spawning
-#pM<-0.5                                            #prop. M before spawning
-
-
-sbpr<-function(age=NULL,ssbwgt=NULL,partial=NULL,pmat=pmat,M=NULL,pF=NULL, pM=NULL,MSP=40,plus=FALSE,oldest=NULL,maxF=2,incrF=0.0001){				
+sbpr<-function(age=NULL,ssbwgt=NULL,partial=NULL,pmat=pmat,M=NULL,pF=NULL, pM=NULL,MSP=40,plus=FALSE,oldest=NULL,maxF=2,incrF=0.0001,graph=TRUE){				
 	if(is.null(age)) 
          stop ("age vector is missing") 
   	if(is.null(ssbwgt)) 
@@ -68,7 +58,6 @@ for (i in 1:length(SPR$F))
    sss<-NULL
 ###Calculate F for percent MSP
    getF<-function(x){
-
    data$SB<-exp(-(data$partial*data$pF*x+data$pM*data$M))
    data$S<-cumprod(exp(-(data$partial*x+data$M)))
    data$psb[1]<-1
@@ -86,7 +75,11 @@ for (i in 1:length(SPR$F))
   ans<-rbind(cbind(Fsp,sss)) 
   dimnames(ans)<-list(c(paste("F at ",MSP,"%MSP",sep="")),c("F","SSB_Per_Recruit"))  
   outpt<-list(ans,SPR);names(outpt)<-c("Reference_Point","F_vs_SPR")
+  if(graph==TRUE){
+    par(mfrow=c(1,2))
+    plot(SPR[,2]~SPR[,1],ylab="SPR",xlab="F",type="l")
+    plot(SPR[,3]~SPR[,1],ylab="% Max SPR",xlab="F",type="l")
+  }
   return(outpt)
 }
-#sbpr(age=age,ssbwgt=ssbwgt,partial=prec,
-#pmat=pmat,M=0.2,pF=0.2,pM=0.1667,MSP=40,plus=T,maxF=2,incrF=0.001)		
+
